"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class UniversalUpscalerStyle(str, Enum):
    r"""The style to upscale images using universal upscaler with."""
    GENERAL = 'GENERAL'
    CINEMATIC = 'CINEMATIC'
    TWO_D_ART_AND_ILLUSTRATION = '2D ART & ILLUSTRATION'
    CG_ART_AND_GAME_ASSETS = 'CG ART & GAME ASSETS'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ControlnetType(str, Enum):
    r"""This parameter will be deprecated in September 2024. Please use the controlnets array instead.

    Deprecated class: This will be removed in a future release, please migrate away from it as soon as possible.
    """
    POSE = 'POSE'
    CANNY = 'CANNY'
    DEPTH = 'DEPTH'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class LcmGenerationStyle(str, Enum):
    r"""The style to generate LCM images with."""
    ANIME = 'ANIME'
    CINEMATIC = 'CINEMATIC'
    DIGITAL_ART = 'DIGITAL_ART'
    DYNAMIC = 'DYNAMIC'
    ENVIRONMENT = 'ENVIRONMENT'
    FANTASY_ART = 'FANTASY_ART'
    ILLUSTRATION = 'ILLUSTRATION'
    PHOTOGRAPHY = 'PHOTOGRAPHY'
    RENDER_3_D = 'RENDER_3D'
    RAYTRACED = 'RAYTRACED'
    SKETCH_BW = 'SKETCH_BW'
    SKETCH_COLOR = 'SKETCH_COLOR'
    VIBRANT = 'VIBRANT'
    NONE = 'NONE'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from dataclasses_json import Undefined, dataclass_json
from leonardoaisdk import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class UploadCanvasInitImageRequestBody:
    r"""Query parameters provided in the request body as a JSON object"""
    init_extension: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('initExtension') }})
    r"""Has to be png, jpg, jpeg, or webp."""
    mask_extension: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('maskExtension') }})
    r"""Has to be png, jpg, jpeg, or webp."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CanvasInitImageUploadOutput:
    UNSET='__SPEAKEASY_UNSET__'
    init_fields: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('initFields'), 'exclude': lambda f: f is CanvasInitImageUploadOutput.UNSET }})
    init_image_id: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('initImageId'), 'exclude': lambda f: f is CanvasInitImageUploadOutput.UNSET }})
    init_key: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('initKey'), 'exclude': lambda f: f is CanvasInitImageUploadOutput.UNSET }})
    init_url: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('initUrl'), 'exclude': lambda f: f is CanvasInitImageUploadOutput.UNSET }})
    mask_fields: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('maskFields'), 'exclude': lambda f: f is CanvasInitImageUploadOutput.UNSET }})
    mask_image_id: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('maskImageId'), 'exclude': lambda f: f is CanvasInitImageUploadOutput.UNSET }})
    mask_key: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('maskKey'), 'exclude': lambda f: f is CanvasInitImageUploadOutput.UNSET }})
    mask_url: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('maskUrl'), 'exclude': lambda f: f is CanvasInitImageUploadOutput.UNSET }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class UploadCanvasInitImageResponseBody:
    r"""Responses for POST /canvas-init-image"""
    UNSET='__SPEAKEASY_UNSET__'
    upload_canvas_init_image: Optional[CanvasInitImageUploadOutput] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uploadCanvasInitImage'), 'exclude': lambda f: f is UploadCanvasInitImageResponseBody.UNSET }})
    



@dataclasses.dataclass
class UploadCanvasInitImageResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    raw_response: requests_http.Response = dataclasses.field()
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: Optional[UploadCanvasInitImageResponseBody] = dataclasses.field(default=None)
    r"""Responses for POST /canvas-init-image"""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""


import requests as requests_http
from ._hooks import SDKHooks
from .utils import utils
from .utils.retries import RetryConfig
from dataclasses import dataclass
from leonardoaisdk.models import shared
from typing import Callable, Dict, Optional, Tuple, Union


SERVERS = [
    'https://cloud.leonardo.ai/api/rest/v1',
    # Leonardo.Ai API server
]
"""Contains the list of servers available to the SDK"""

@dataclass
class SDKConfiguration:
    client: requests_http.Session
    security: Union[shared.Security,Callable[[], shared.Security]] = None
    server_url: Optional[str] = ''
    server_idx: Optional[int] = 0
    language: str = 'python'
    openapi_doc_version: str = 'v1.0.0'
    sdk_version: str = '5.5.3'
    gen_version: str = '2.340.3'
    user_agent: str = 'speakeasy-sdk/python 5.5.3 2.340.3 v1.0.0 Leonardo-Ai-SDK'
    retry_config: Optional[RetryConfig] = None

    def __post_init__(self):
        self._hooks = SDKHooks()

    def get_server_details(self) -> Tuple[str, Dict[str, str]]:
        if self.server_url is not None and self.server_url != '':
            return utils.remove_suffix(self.server_url, '/'), {}
        if self.server_idx is None:
            self.server_idx = 0

        return SERVERS[self.server_idx], {}


    def get_hooks(self) -> SDKHooks:
        return self._hooks



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ...models.shared import custom_model_type as shared_custom_model_type
from ...models.shared import job_status as shared_job_status
from ...models.shared import sd_versions as shared_sd_versions
from dataclasses_json import Undefined, dataclass_json
from leonardoaisdk import utils
from typing import Optional


@dataclasses.dataclass
class GetModelByIDRequest:
    id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'id', 'style': 'simple', 'explode': False }})
    r"""The ID of the custom model to return."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetModelByIDCustomModels:
    r"""columns and relationships of \\"custom_models\\" """
    UNSET='__SPEAKEASY_UNSET__'
    created_at: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('createdAt'), 'exclude': lambda f: f is None }})
    description: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('description'), 'exclude': lambda f: f is None }})
    id: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id'), 'exclude': lambda f: f is GetModelByIDCustomModels.UNSET }})
    instance_prompt: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('instancePrompt'), 'exclude': lambda f: f is GetModelByIDCustomModels.UNSET }})
    model_height: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('modelHeight'), 'exclude': lambda f: f is None }})
    model_width: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('modelWidth'), 'exclude': lambda f: f is None }})
    name: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name'), 'exclude': lambda f: f is None }})
    public: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('public'), 'exclude': lambda f: f is None }})
    sd_version: Optional[shared_sd_versions.SdVersions] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('sdVersion'), 'exclude': lambda f: f is None }})
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5. Also includes SDXL and SDXL Lightning models"""
    status: Optional[shared_job_status.JobStatus] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status'), 'exclude': lambda f: f is None }})
    r"""The status of the current task."""
    type: Optional[shared_custom_model_type.CustomModelType] = dataclasses.field(default=shared_custom_model_type.CustomModelType.GENERAL, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type'), 'exclude': lambda f: f is None }})
    r"""The category the most accurately reflects the model."""
    updated_at: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('updatedAt'), 'exclude': lambda f: f is None }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetModelByIDResponseBody:
    r"""Responses for GET /models/{id}"""
    UNSET='__SPEAKEASY_UNSET__'
    custom_models_by_pk: Optional[GetModelByIDCustomModels] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('custom_models_by_pk'), 'exclude': lambda f: f is GetModelByIDResponseBody.UNSET }})
    r"""columns and relationships of \\"custom_models\\" """
    



@dataclasses.dataclass
class GetModelByIDResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    raw_response: requests_http.Response = dataclasses.field()
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: Optional[GetModelByIDResponseBody] = dataclasses.field(default=None)
    r"""Responses for GET /models/{id}"""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CanvasRequestType(str, Enum):
    r"""The type of request for the Canvas Editor."""
    INPAINT = 'INPAINT'
    OUTPAINT = 'OUTPAINT'
    SKETCH2_IMG = 'SKETCH2IMG'
    IMG2_IMG = 'IMG2IMG'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from leonardoaisdk import utils
from typing import Optional


class InitImageType(str, Enum):
    r"""Type indicating whether the init image is uploaded or generated."""
    GENERATED = 'GENERATED'
    UPLOADED = 'UPLOADED'


class StrengthType(str, Enum):
    r"""Strength type for the controlnet. Can only be used for Style, Character and Content Reference controlnets."""
    LOW = 'Low'
    MID = 'Mid'
    HIGH = 'High'
    ULTRA = 'Ultra'
    MAX = 'Max'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ControlnetInput:
    UNSET='__SPEAKEASY_UNSET__'
    init_image_id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('initImageId'), 'exclude': lambda f: f is None }})
    r"""The ID of the init image"""
    init_image_type: Optional[InitImageType] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('initImageType'), 'exclude': lambda f: f is None }})
    r"""Type indicating whether the init image is uploaded or generated."""
    preprocessor_id: Optional[float] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('preprocessorId'), 'exclude': lambda f: f is None }})
    r"""ID of the controlnet. A list of compatible IDs can be found in our guides."""
    strength_type: Optional[StrengthType] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('strengthType'), 'exclude': lambda f: f is ControlnetInput.UNSET }})
    r"""Strength type for the controlnet. Can only be used for Style, Character and Content Reference controlnets."""
    weight: Optional[float] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('weight'), 'exclude': lambda f: f is ControlnetInput.UNSET }})
    r"""Weight for the controlnet"""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .canvasrequesttype import *
from .controlnet_input import *
from .controlnet_type import *
from .custom_model_type import *
from .element_input import *
from .job_status import *
from .lcm_generation_style import *
from .model_asset_texture_types import *
from .pricingcalculatorservices import *
from .sd_generation_schedulers import *
from .sd_generation_style import *
from .sd_versions import *
from .security import *
from .strength import *
from .universal_upscaler_style import *
from .variation_type import *

__all__ = ["CanvasRequestType","ControlnetInput","ControlnetType","CustomModelType","ElementInput","InitImageType","JobStatus","LcmGenerationStyle","ModelAssetTextureTypes","PricingCalculatorServices","SdGenerationSchedulers","SdGenerationStyle","SdVersions","Security","Strength","StrengthType","UniversalUpscalerStyle","VariationType"]



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SdVersions(str, Enum):
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5. Also includes SDXL and SDXL Lightning models"""
    V1_5 = 'v1_5'
    V2 = 'v2'
    V3 = 'v3'
    SDXL_0_8 = 'SDXL_0_8'
    SDXL_0_9 = 'SDXL_0_9'
    SDXL_1_0 = 'SDXL_1_0'
    SDXL_LIGHTNING = 'SDXL_LIGHTNING'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ...models.shared import job_status as shared_job_status
from ...models.shared import variation_type as shared_variation_type
from dataclasses_json import Undefined, dataclass_json
from leonardoaisdk import utils
from typing import List, Optional


@dataclasses.dataclass
class GetVariationByIDRequest:
    id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'id', 'style': 'simple', 'explode': False }})
    r"""\\"id\\" is required"""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GeneratedImageVariationGeneric:
    r"""columns and relationships of \\"generated_image_variation_generic\\" """
    UNSET='__SPEAKEASY_UNSET__'
    created_at: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('createdAt'), 'exclude': lambda f: f is None }})
    id: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id'), 'exclude': lambda f: f is GeneratedImageVariationGeneric.UNSET }})
    status: Optional[shared_job_status.JobStatus] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status'), 'exclude': lambda f: f is None }})
    r"""The status of the current task."""
    transform_type: Optional[shared_variation_type.VariationType] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('transformType'), 'exclude': lambda f: f is None }})
    r"""The type of variation."""
    url: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('url'), 'exclude': lambda f: f is GeneratedImageVariationGeneric.UNSET }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetVariationByIDResponseBody:
    r"""Responses for GET /variations/{id}"""
    generated_image_variation_generic: Optional[List[GeneratedImageVariationGeneric]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('generated_image_variation_generic'), 'exclude': lambda f: f is None }})
    



@dataclasses.dataclass
class GetVariationByIDResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    raw_response: requests_http.Response = dataclasses.field()
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: Optional[GetVariationByIDResponseBody] = dataclasses.field(default=None)
    r"""Responses for GET /variations/{id}"""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ...models.shared import universal_upscaler_style as shared_universal_upscaler_style
from dataclasses_json import Undefined, dataclass_json
from leonardoaisdk import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CreateUniversalUpscalerJobRequestBody:
    r"""Query parameters are provided in the request body as a JSON object"""
    UNSET='__SPEAKEASY_UNSET__'
    creativity_strength: Optional[int] = dataclasses.field(default=5, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('creativityStrength'), 'exclude': lambda f: f is CreateUniversalUpscalerJobRequestBody.UNSET }})
    r"""The creativity strength of the universal upscaler, must be integer between 1 and 10"""
    generated_image_id: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('generatedImageId'), 'exclude': lambda f: f is CreateUniversalUpscalerJobRequestBody.UNSET }})
    r"""The ID of the generated image"""
    init_image_id: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('initImageId'), 'exclude': lambda f: f is CreateUniversalUpscalerJobRequestBody.UNSET }})
    r"""The ID of the init image uploaded"""
    prompt: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('prompt'), 'exclude': lambda f: f is CreateUniversalUpscalerJobRequestBody.UNSET }})
    r"""The prompt for the universal upscaler"""
    upscale_multiplier: Optional[float] = dataclasses.field(default=1.5, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('upscaleMultiplier'), 'exclude': lambda f: f is CreateUniversalUpscalerJobRequestBody.UNSET }})
    r"""The upscale multiplier of the universal upscaler, must be number between 1.00 and 2.00"""
    upscaler_style: Optional[shared_universal_upscaler_style.UniversalUpscalerStyle] = dataclasses.field(default=shared_universal_upscaler_style.UniversalUpscalerStyle.GENERAL, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('upscalerStyle'), 'exclude': lambda f: f is CreateUniversalUpscalerJobRequestBody.UNSET }})
    r"""The style to upscale images using universal upscaler with."""
    variation_id: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('variationId'), 'exclude': lambda f: f is CreateUniversalUpscalerJobRequestBody.UNSET }})
    r"""The ID of the variation image"""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class UniversalUpscalerOutput:
    UNSET='__SPEAKEASY_UNSET__'
    api_credit_cost: Optional[int] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('apiCreditCost'), 'exclude': lambda f: f is UniversalUpscalerOutput.UNSET }})
    r"""API Credits Cost for Universal Upscaler Variation. Available for Production API Users."""
    id: Optional[str] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id'), 'exclude': lambda f: f is UniversalUpscalerOutput.UNSET }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CreateUniversalUpscalerJobResponseBody:
    r"""Responses for POST /variations/universal-upscaler"""
    universal_upscaler: Optional[UniversalUpscalerOutput] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('universalUpscaler'), 'exclude': lambda f: f is None }})
    



@dataclasses.dataclass
class CreateUniversalUpscalerJobResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    raw_response: requests_http.Response = dataclasses.field()
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: Optional[CreateUniversalUpscalerJobResponseBody] = dataclasses.field(default=None)
    r"""Responses for POST /variations/universal-upscaler"""
    

